@@ -41,10 +41,10 @@ namespace Kwave
 	WavEncoder();
 
 	/** Destructor */
-	virtual ~WavEncoder();
+        virtual ~WavEncoder() Q_DECL_OVERRIDE;
 
 	/** Returns a new instance of the encoder */
-	Encoder *instance() Q_DECL_OVERRIDE;
+        virtual Encoder *instance() Q_DECL_OVERRIDE;
 
 	/**
 	 * Encodes a signal into a stream of bytes.
@@ -55,12 +55,14 @@ namespace Kwave
 	 * @param meta_data meta data of the file to save
 	 * @return true if succeeded, false on errors
 	 */
-	bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
-	            QIODevice &dst, const Kwave::MetaDataList &meta_data)
+        virtual bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
+	                    QIODevice &dst,
+                            const Kwave::MetaDataList &meta_data)
             Q_DECL_OVERRIDE;
 
 	/** Returns a list of supported file properties */
-	QList<Kwave::FileProperty> supportedProperties() Q_DECL_OVERRIDE;
+        virtual QList<Kwave::FileProperty> supportedProperties()
+            Q_DECL_OVERRIDE;
 
     private:
 
