@@ -789,7 +789,7 @@ void Kwave::PlayBackPulseAudio::scanDevices()
     // fetch the device list from the PulseAudio server
     m_mainloop_lock.lock();
     m_device_list.clear();
-    pa_operation *op_sink_info = pa_context_get_sink_info_list(
+    const pa_operation *op_sink_info = pa_context_get_sink_info_list(
 	m_pa_context,
 	pa_sink_info_cb,
 	this
