@@ -443,7 +443,7 @@ void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
 
 		if (item) {
 		    // already in the list
-		    parent = item;
+		    /* parent = item; */
 		} else if (parent) {
 		    // new leaf, add to the parent
 		    item = new(std::nothrow) QTreeWidgetItem(parent);
@@ -631,7 +631,7 @@ void Kwave::RecordDialog::selectRecordDevice()
         dlg->selectUrl(QUrl(_("file:") + m_params.device_name));
     else
         dlg->selectUrl(QUrl(_("file:/dev/*")));
-    if ((dlg->exec() == QDialog::Accepted) && dlg) {
+    if (dlg->exec() == QDialog::Accepted) {
 	// selected new device
 	QString new_device = dlg->selectedUrl().path();
 	if (new_device != m_params.device_name)
@@ -1338,7 +1338,8 @@ void Kwave::RecordDialog::updateRecordButton()
     // enabled if not disabled by status and also not limited or
     // less than the limit has been recorded
     new_enable = m_record_enabled && (!m_params.record_time_limited ||
-        (m_samples_recorded < m_params.record_time * m_params.sample_rate));
+	(static_cast<double>(m_samples_recorded) <
+         m_params.record_time * m_params.sample_rate));
 
     if (new_enable != old_enable) btRecord->setEnabled(new_enable);
 }
